@@ -3,9 +3,17 @@ import json
 import importlib
 from langtrace_python_sdk.constants.instrumentation.anthropic import APIS
 from langtrace_python_sdk.constants import LANGTRACE_SDK_NAME
-from tests.utils import assert_response_format, assert_token_count
+from tests.utils import (
+    assert_completion_in_events,
+    assert_langtrace_attributes,
+    assert_prompt_in_events,
+    assert_response_format,
+    assert_token_count,
+)
 from importlib_metadata import version as v
 
+from langtrace.trace_attributes import SpanAttributes
+
 
 @pytest.mark.vcr()
 def test_anthropic(anthropic_client, exporter):
@@ -25,22 +33,17 @@ def test_anthropic(anthropic_client, exporter):
 
     assert completion_span.name == "anthropic.messages.create"
     attributes = completion_span.attributes
-
-    assert attributes.get("langtrace.sdk.name") == "langtrace-python-sdk"
-    assert attributes.get("langtrace.service.name") == "Anthropic"
-    assert attributes.get("langtrace.service.type") == "llm"
-    assert attributes.get("langtrace.service.version") == importlib.metadata.version(
-        "anthropic"
+    assert_langtrace_attributes(attributes, "Anthropic")
+    assert_prompt_in_events(completion_span.events)
+    assert_completion_in_events(completion_span.events)
+    assert attributes.get(SpanAttributes.LLM_URL) == "https://api.anthropic.com"
+    assert (
+        attributes.get(SpanAttributes.LLM_PATH) == APIS["MESSAGES_CREATE"]["ENDPOINT"]
     )
-    assert attributes.get("langtrace.version") == v(LANGTRACE_SDK_NAME)
-    assert attributes.get("url.full") == "https://api.anthropic.com"
-    assert attributes.get("llm.api") == APIS["MESSAGES_CREATE"]["ENDPOINT"]
-    assert attributes.get("llm.model") == llm_model_value
-    assert attributes.get("llm.prompts") == json.dumps(messages_value)
-    assert attributes.get("llm.stream") is False
+    assert attributes.get(SpanAttributes.LLM_REQUEST_MODEL) == llm_model_value
+    assert attributes.get(SpanAttributes.LLM_IS_STREAMING) is False
 
     assert_token_count(attributes)
-    assert_response_format(attributes)
 
 
 @pytest.mark.vcr()
@@ -68,21 +71,19 @@ def test_anthropic_streaming(anthropic_client, exporter):
     assert streaming_span.name == "anthropic.messages.create"
     attributes = streaming_span.attributes
 
-    assert attributes.get("langtrace.sdk.name") == "langtrace-python-sdk"
-    assert attributes.get("langtrace.service.name") == "Anthropic"
-    assert attributes.get("langtrace.service.type") == "llm"
-    assert attributes.get("langtrace.service.version") == importlib.metadata.version(
-        "anthropic"
+    assert_langtrace_attributes(attributes, "Anthropic")
+    assert_prompt_in_events(streaming_span.events)
+    assert_completion_in_events(streaming_span.events)
+
+    assert attributes.get(SpanAttributes.LLM_URL) == "https://api.anthropic.com"
+    assert (
+        attributes.get(SpanAttributes.LLM_PATH) == APIS["MESSAGES_CREATE"]["ENDPOINT"]
     )
-    assert attributes.get("langtrace.version") == v(LANGTRACE_SDK_NAME)
-    assert attributes.get("url.full") == "https://api.anthropic.com"
-    assert attributes.get("llm.api") == APIS["MESSAGES_CREATE"]["ENDPOINT"]
-    assert attributes.get("llm.model") == llm_model_value
-    assert attributes.get("llm.prompts") == json.dumps(messages_value)
-    assert attributes.get("llm.stream") is True
+    assert attributes.get(SpanAttributes.LLM_REQUEST_MODEL) == llm_model_value
+    assert attributes.get(SpanAttributes.LLM_IS_STREAMING) is True
+
     events = streaming_span.events
 
-    assert len(events) - 2 == chunk_count  # -2 for start and end events
+    assert len(events) - 4 == chunk_count
 
     assert_token_count(attributes)
-    assert_response_format(attributes)
